@@ -166,7 +166,7 @@ def zip_location(filename: str) -> tuple[str, str] | None:
     name is in the zipfile.
 
     """
-    for ext in [".zip", ".whl", ".egg", ".pex"]:
+    for ext in [".zip", ".whl", ".egg", ".pex", ".par"]:
         zipbase, extension, inner = filename.partition(ext + sep(filename))
         if extension:
             zipfile = zipbase + ext
@@ -332,7 +332,7 @@ def _glob_to_regex(pattern: str) -> str:
     # Turn all backslashes into slashes to simplify the tokenizer.
     pattern = pattern.replace("\\", "/")
     if "/" not in pattern:
-        pattern = "**/" + pattern
+        pattern = f"**/{pattern}"
     path_rx = []
     pos = 0
     while pos < len(pattern):
