@@ -207,6 +207,8 @@ class PythonParserTest(PythonParserTestBase):
             )
             """)
         assert parser.exit_counts() == {1: 1}
+        # In conftest.py, we silence the SyntaxWarning this code causes. If
+        # we remove this code, we can probably remove that warning.
         parser = self.parse_text("""\
             def g2():
                 try:
@@ -216,6 +218,10 @@ class PythonParserTest(PythonParserTestBase):
             """)
         assert parser.exit_counts() == {1: 1, 2: 1, 3: 1, 5: 1}
 
+    def test_fuzzed_weirdness(self) -> None:
+        # This used to cause a `min of empty sequence` error:
+        self.parse_text("\r\\\n\n\t\t\\\n\n")
+
 
 class ExclusionParserTest(PythonParserTestBase):
     """Tests for the exclusion code in PythonParser."""
@@ -1181,7 +1187,7 @@ class ParserFileTest(CoverageTest):
                 stderr=subprocess.PIPE).communicate()""")   # no final newline.
 
         # Double-check that some test helper wasn't being helpful.
-        with open("abrupt.py") as f:
+        with open("abrupt.py", encoding="utf-8") as f:
             assert f.read()[-1] == ")"
 
         parser = self.parse_file("abrupt.py")
